package ar.com.unobtainium.tonetennis.elements 
{
	import flash.display.DisplayObject;
	import flash.display.Sprite;
	import com.greensock.*;
	
	/**
	 * Stateful input representation
	 * @author Balthazar Auger
	 */
	public class Pad extends Sprite 
	{
		
		public static const MAX_WIDTH:int = 200;
		public static const WIDTH_UNIT:int = 25;
		
		public static const ZONE_COLOR:uint = 0x333333;
		
		
		protected var _padHeight:int = 40;
		
		protected var _padFillColor:uint = 0xFFFFFF;
		protected var _zoneFillColor:uint;
		
		protected var zone:Sprite;
		protected var textField:PixelTextField;
		
		//Make this display the current action that will be triggered when pressing the pad
		//protected var textInfo:Sprite;
		
		public var isPressed:Boolean = false;
		
		public function Pad(color:uint = ZONE_COLOR) 
		{
			super();
			
			_zoneFillColor = color;
			
			this.draw();
			
		}
		
		protected function draw():void
		{
			this.graphics.clear();
			
			this.zone = new Sprite();
			
			//draw the background
			this.zone.graphics.beginFill(_zoneFillColor);
			this.zone.graphics.drawRect(-MAX_WIDTH/2, 0, MAX_WIDTH, 720);
			this.zone.graphics.endFill();
			
			this.addChild(zone);

			this.textField = new PixelTextField();
			this.textField.y = this.zone.height / 2 + 80;
			this.addChild(textField);
			
			this.alpha = 0.8;
		}
		
		public function collidesWith(obj:DisplayObject):Boolean
		{
			var collides:Boolean = zone.hitTestObject(obj);
			return collides;
		}
		
		public function press():void
		{
			isPressed = true;
			TweenMax.to(this, 0.2, { alpha:1 } );
		}
		
		public function release():void
		{
			isPressed = false;
			TweenMax.to(this, 0.7, { alpha:0.8 } );
		}
		
		
		public function setText(text:String):void
		{
			var letters:Array = text.split('');
			
			var vertText:String = '';
			
			for each (var letter:String in letters)
			{
				vertText += letter + "\r";
			}
			
			var timeline:TimelineMax = new TimelineMax();
			
			timeline.append(new TweenMax(this.textField, 0.1, { alpha:0 } ));
			timeline.addCallback(changeText,0.1,[vertText]);
			timeline.append(new TweenMax(this.textField, 0.1, { alpha:1 } ));
			
			timeline.play();
			
		}
		
		private function changeText(newText:String):void
		{
			this.textField.text = newText;
			this.textField.x = -(this.textField.textWidth / 2);
		}
		
		// TODO: add "prompt" state that should tell the player to press that pad
		public function prompt():void
		{
			
		}
		
		public function unprompt():void
		{
			
		}
		
		public function shrink():void
		{
			TweenMax.to(this.zone, 0.3, { width: "-" + WIDTH_UNIT } );
		}
		
		public function restoreWidth():void
		{
			TweenMax.to(this.zone, 0.3, { width: MAX_WIDTH } );
		}
	}
}